@@ -63,17 +63,17 @@ from ansible.plugins.loader import (
 )
 from ansible.template import Templar
 from ansible.utils.collection_loader import AnsibleCollectionConfig
+from jinja2 import Environment, nodes
+from jinja2.exceptions import TemplateError, TemplateSyntaxError
+from packaging.version import Version
 from yaml.composer import Composer
 from yaml.parser import ParserError
 from yaml.representer import RepresenterError
 from yaml.scanner import ScannerError
 
-from ansiblelint._internal.rules import (
-    AnsibleParserErrorRule,
-    RuntimeErrorRule,
-)
+from ansiblelint._internal.rules import AnsibleParserErrorRule, RuntimeErrorRule
 from ansiblelint.app import App, get_app
-from ansiblelint.config import Options, options
+from ansiblelint.config import Options, get_deps_versions, options
 from ansiblelint.constants import (
     ANNOTATION_KEYS,
     FILENAME_KEY,
@@ -168,6 +168,32 @@ def mock_filter(left: Any, *args: Any, **kwargs: Any) -> Any:  # noqa: ARG001
     return left
 
 
+def has_lookup_function_calls(varname: str) -> bool:
+    """Check if a template string contains lookup, query, or q function calls using AST parsing.
+
+    This function parses Jinja2 templates and looks for function calls to
+    'lookup', 'query', or 'q' by examining the AST).
+
+    :param varname: The template string to analyze
+    :return: True if lookup functions are found, False otherwise
+    """
+    lookup_names = {"lookup", "query", "q"}
+
+    try:
+        env = Environment(autoescape=True)
+        ast_tree = env.parse(varname)
+
+        for node in ast_tree.find_all(nodes.Call):
+            if isinstance(node.node, nodes.Name) and node.node.name in lookup_names:
+                return True
+    except (TemplateSyntaxError, TemplateError, AttributeError):
+        # Fallback to regex for edge cases where Jinja2 parsing fails
+        fallback_pattern = re.compile(r"\(?(lookup|query|q)\)?\s*\(")
+        return bool(fallback_pattern.search(varname))
+    else:
+        return False
+
+
 def ansible_template(
     basedir: Path,
     varname: Any,
@@ -177,7 +203,7 @@ def ansible_template(
     """Render a templated string by mocking missing filters.
 
     In the case of a missing lookup, ansible core does an early exit
-    but this happens after the jinja2 syntax already passed
+    when disable_lookup=True but this happens after the jinja2 syntax already passed
     return the original string as if it had been templated.
 
     In the case of a missing filter, extract the missing filter plugin name
@@ -200,6 +226,14 @@ def ansible_template(
     re_filter_in_err = re.compile(r"Could not load \"(\w+)\"")
     re_valid_filter = re.compile(r"^\w+(\.\w+\.\w+)?$")
     templar = ansible_templar(basedir=basedir, templatevars=templatevars)
+    ansible_core_2_19 = Version("2.19")
+    deps = get_deps_versions()
+
+    # Skip lookups for ansible-core >= 2.19; use disable_lookups for older versions
+    if has_lookup_function_calls(str(varname)):
+        if deps["ansible-core"] and deps["ansible-core"] >= ansible_core_2_19:
+            return varname
+        kwargs["disable_lookups"] = True
 
     for _i in range(10):
         try:
@@ -319,7 +353,7 @@ def template(
         )
         # Hack to skip the following exception when using to_json filter on a variable. # noqa: FIX004
         # I guess the filter doesn't like empty vars...
-    except (AnsibleError, ValueError, RepresenterError):
+    except (AnsibleError, ValueError, RepresenterError, ImportError):
         # templating failed, so just keep value as is.
         if fail_on_error:
             raise
@@ -1310,7 +1344,7 @@ def parse_examples_from_plugin(lintable: Lintable) -> tuple[int, str]:
                 offset = child.lineno - 1
                 break
 
-    docs = read_docstring(str(lintable.path))  # type: ignore[no-untyped-call]
+    docs = read_docstring(str(lintable.path.resolve(strict=False)))  # type: ignore[no-untyped-call]
     examples = docs["plainexamples"]
 
     # Ignore the leading newline and lack of document start
